
#include <gtk/gtk.h>
#include <string.h>
#include <gconf/gconf-client.h>
#include <libedataserver/e-source-list.h>
#include "e-contact-entry.h"

#define GCONF_COMPLETION "/apps/evolution/addressbook"
#define GCONF_COMPLETION_SOURCES GCONF_COMPLETION "/sources"

static void
add_sources (EContactEntry *entry)
{
	ESourceList *source_list;

	source_list =
		e_source_list_new_for_gconf_default (GCONF_COMPLETION_SOURCES);
	e_contact_entry_set_source_list (E_CONTACT_ENTRY (entry),
			source_list);
	g_object_unref (source_list);
}

static char *
test_display_func (EContact *contact, gpointer data)
{
	const char *mobile;

	/* No contacts without a mobile phone in the list */
	mobile = e_contact_get_const (contact, E_CONTACT_PHONE_MOBILE);
	if (mobile == NULL) {
		return NULL;
	}
	return g_strdup_printf ("%s <%s>", (char*)e_contact_get_const (contact, E_CONTACT_NAME_OR_ORG), mobile);
}

int main (int argc, char **argv)
{
	GtkWidget *window, *entry;
	EContactField fields[] = { E_CONTACT_FULL_NAME, E_CONTACT_NICKNAME, E_CONTACT_ORG, E_CONTACT_PHONE_MOBILE, 0 };

	gtk_init (&argc, &argv);

	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	entry = e_contact_entry_new ();
	add_sources (E_CONTACT_ENTRY (entry));
	//FIXME connect the few signals
	e_contact_entry_set_search_fields (E_CONTACT_ENTRY (entry), (const EContactField *)fields);
	e_contact_entry_set_display_func (E_CONTACT_ENTRY (entry), test_display_func, NULL, NULL);
	gtk_container_add (GTK_CONTAINER (window), entry);

	gtk_widget_show_all (window);

	gtk_main ();

	return 0;
}

